@@ -8,6 +8,8 @@ import shutil
 import subprocess
 import sys
 import tempfile
+from collections import defaultdict
+from itertools import chain
 from pathlib import Path
 from typing import Dict, Iterator, List, Optional, Tuple
 
@@ -19,6 +21,14 @@ from nbqa import (
     save_source,
 )
 
+CONFIG_FILES: Dict[str, List[str]] = defaultdict(
+    lambda: ["setup.cfg", "tox.ini", "pyproject.toml", ".editorconfig"]
+)
+CONFIG_FILES["flake8"].extend([".flake8"])
+CONFIG_FILES["mypy"].extend(["mypy.ini", ".mypy.ini"])
+CONFIG_FILES["isort"].extend([".isort.cfg"])
+CONFIG_FILES["pytest"].extend(["pytest.ini"])
+
 
 def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
     """
@@ -33,8 +43,8 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
     -------
     command
         The third-party tool to run (e.g. :code:`mypy`).
-    root_dir
-        The notebook or directory to run third-party tool on.
+    root_dirs
+        The notebooks or directories to run third-party tool on.
     kwargs
         Any additional flags passed to third-party tool (e.g. :code:`--quiet`).
 
@@ -52,7 +62,9 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
         ),
     )
     parser.add_argument("command", help="Command to run, e.g. `flake8`.")
-    parser.add_argument("root_dir", help="Notebook or directory to run command on.")
+    parser.add_argument(
+        "root_dirs", nargs="+", help="Notebooks or directories to run command on."
+    )
     parser.add_argument("--version", action="version", version=f"nbQA {__version__}")
     try:
         args, kwargs = parser.parse_known_args(raw_args)
@@ -63,10 +75,10 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
                 "nbqa flake8 my_notebook.ipynb"
             )
             raise ValueError(msg) from exception
-        sys.exit(0)
+        sys.exit(0)  # pragma: nocover
     command = args.command
-    root_dir = args.root_dir
-    return command, root_dir, kwargs
+    root_dirs = args.root_dirs
+    return command, root_dirs, kwargs
 
 
 def _get_notebooks(root_dir: str) -> Iterator[Path]:
@@ -86,7 +98,7 @@ def _get_notebooks(root_dir: str) -> Iterator[Path]:
     if not Path(root_dir).is_dir():
         return (i for i in (Path(root_dir),))
     notebooks = (
-        i for i in Path(".").rglob("*.ipynb") if ".ipynb_checkpoints" not in str(i)
+        i for i in Path(root_dir).rglob("*.ipynb") if ".ipynb_checkpoints" not in str(i)
     )
     return notebooks
 
@@ -343,6 +355,29 @@ def _create_blank_init_files(notebook: Path, tmpdirname: str) -> None:
         Path(tmpdirname).joinpath(i).touch()
 
 
+def _preserve_config_files(command: str, tmpdirname: str) -> None:
+    """
+    Copy local config files to temporary directory.
+
+    Parameters
+    ----------
+    command
+        Third-party tool (e.g. mypy).
+    tmpdirname
+        Temporary directory to store converted notebooks in.
+    """
+    config_files = (
+        i
+        for i in chain(*(Path.cwd().rglob(j) for j in CONFIG_FILES[command]))
+        if i.is_file()
+    )
+    for i in config_files:
+        Path(tmpdirname).joinpath(i.relative_to(Path.cwd())).parent.mkdir(
+            parents=True, exist_ok=True
+        )
+        shutil.copy(str(i), str(Path(tmpdirname).joinpath(i.relative_to(Path.cwd()))))
+
+
 def _ensure_cell_separators_remain(temp_python_file: Path) -> None:
     """
     Reinstate blank line which separates the cells (may be removed by isort).
@@ -463,18 +498,24 @@ def _run_command(
     return out, err, output_code
 
 
-def main(raw_args: Optional[List[str]] = None) -> None:
+def _run_on_one_root_dir(root_dir: str, command: str, kwargs: List[str]) -> int:
     """
-    Run third-party tool (e.g. :code:`mypy`) against notebook or directory.
+    Run third-party tool on a single notebook or directory.
 
     Parameters
     ----------
-    raw_args
-        Command-line arguments (if calling this function directly), defaults to
-        :code:`None` if calling via command-line.
-    """
-    command, root_dir, kwargs = _parse_args(raw_args)
+    root_dir
+        Notebook or directory to run 3rd-party tool on.
+    command
+        Third-party tool (e.g. :code:`mypy`)
+    kwargs
+        Additional flags to pass to 3rd party tool
 
+    Returns
+    -------
+    int
+        Output code from third-party tool.
+    """
     notebooks = _get_notebooks(root_dir)
 
     with tempfile.TemporaryDirectory() as tmpdirname:
@@ -488,15 +529,12 @@ def main(raw_args: Optional[List[str]] = None) -> None:
             save_source.main(notebook, temp_python_file)
             replace_magics.main(temp_python_file)
             _create_blank_init_files(notebook, tmpdirname)
+        _preserve_config_files(command, tmpdirname)
 
         config = configparser.ConfigParser(allow_no_value=True)
         config.read(".nbqa.ini")
         if command in config.sections():
-            configs = [
-                [f"--{key}", val] if val is not None else [f"--{key}"]
-                for key, val in config[command].items()
-            ]
-            kwargs.extend([j for i in configs for j in i])
+            kwargs.extend(config[command]["addopts"].split())
         out, err, output_code = _run_command(
             command, root_dir, tmpdirname, nb_to_py_mapping, kwargs
         )
@@ -515,7 +553,24 @@ def main(raw_args: Optional[List[str]] = None) -> None:
         sys.stdout.write(out)
         sys.stderr.write(err)
 
-    sys.exit(output_code)
+    return output_code
+
+
+def main(raw_args: Optional[List[str]] = None) -> None:
+    """
+    Run third-party tool (e.g. :code:`mypy`) against notebook or directory.
+
+    Parameters
+    ----------
+    raw_args
+        Command-line arguments (if calling this function directly), defaults to
+        :code:`None` if calling via command-line.
+    """
+    command, root_dirs, kwargs = _parse_args(raw_args)
+
+    output_codes = [_run_on_one_root_dir(i, command, kwargs) for i in root_dirs]
+
+    sys.exit(int(any(output_codes)))
 
 
 if __name__ == "__main__":
