@@ -1,6 +1,5 @@
 """Uncomment magic IPython lines from converted notebook."""
 
-import re
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:  # pragma: nocover
@@ -17,12 +16,14 @@ def main(temp_python_file: "Path") -> None:
         Temporary Python file notebook was converted to.
     """
     with open(str(temp_python_file), "r") as handle:
-        file = handle.read()
+        file = handle.readlines()
 
-    # cell magics
-    file = re.sub(r"# (%%\w+)", r"\1", file)
-    # line magics
-    file = re.sub(r"# (%\w+)", r"\1", file)
+    file = [
+        i
+        if i == "# %%\n" or not (i.startswith("# %") or i.startswith("# !"))
+        else i[2:]
+        for i in file
+    ]
 
     with open(str(temp_python_file), "w") as handle:
-        handle.write(file)
+        handle.writelines(file)
